.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "2.02",
.\"     date            = "28 January 2004",
.\"     time            = "09:33:51 MST",
.\"     filename        = "bsplit.man",
.\"     address         = "Center for Scientific Computing
.\"                        University of Utah
.\"                        Department of Mathematics, 110 LCB
.\"                        155 S 1400 E RM 233
.\"                        Salt Lake City, UT 84112-0090
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 581 4148",
.\"     URL             = "http://www.math.utah.edu/~beebe",
.\"     checksum        = "65254 186 841 5874",
.\"     email           = "beebe@math.utah.edu, beebe@acm.org,
.\"                        beebe@computer.org (Internet)",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "binary file split",
.\"     supported       = "yes",
.\"     docstring       = "This is the UNIX manual page documentation
.\"                        for bsplit, a binary file splitter.
.\"
.\"                        The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.TH BSPLIT 1 "28 January 2004" "Version 2.02"
.\"=====================================================================
.SH NAME
bsplit \- split a binary file into nnn-byte pieces
.\"=====================================================================
.SH SYNOPSIS
.B bsplit
[
.B \-?
]
[
.BI \- nnn[K|M|G|T|P|E]
]
.if n .ti +\w'\fBbsplit\fP\ 'u
[
.BI \-b " nnn[K|M|G|T|P|E]"
]
[
.B \-h
]
[
.B \-v
]
file(s)
.\"=====================================================================
.SH DESCRIPTION
.B bsplit
splits its argument file(s) into
.IR nnn -byte
pieces.  The size of the pieces is determined by the most-recently
encountered size option.
.PP
Splitting of large files is useful for electronic mail transmission
(32KB is the recommended maximum size), to facilitate FTP file
transfers over connections that experience fatal timeouts for large
files, and for transferring files on personal computer floppy disks.
.PP
The split size is always forced internally to be a multiple of 512,
which is the minimum block size on most current systems.  By ensuring
that the parts are multiples of file system blocksizes, corruption of
the pieces through addition of padding garbage on some record-oriented
file systems can be avoided.
.PP
For text files, where it is desirable to split at line boundaries, use
.BR split (1)
instead.
.PP
The split pieces go into parts named like the argument file, but with
the suffix
.I -mmm
.RI ( -001 ,
.IR -002 ,
etc.).
.PP
If no files are specified, then
.I stdin
is read and split, and the output pieces are named
.IR stdin-001 ,
.IR stdin-002 ,
etc.
.PP
On IBM PC DOS and DEC VMS systems, where only a single period is
allowed in a filename, the suffix is changed to
.I .mmm
and it replaces any file extension present in the filename.
.PP
IBM PC systems running Microsoft Windows (95, 98, and NT) are treated
like DOS systems, even though those systems support long filenames
with multiple periods; that way, the
.B bsplit
executable will still work correctly on an IBM PC DOS system.
.\"=====================================================================
.SH OPTIONS
On IBM PC and DEC VMS systems, the option hyphen prefix, `\-', may be
replaced by a slash, '/'; both are recognized on those systems.  The
documentation below uses only the hyphen prefix.
.PP
Letter case is ignored in option names:
.B \-H
and
.B \-h
are equivalent.
.TP
.B \-?
Give a brief usage display on
.I stderr
and exit with a success status code.
.TP
.BI \-b " nnn[K|M|G|T|P|E]" "\fR or \fP" "" \- nnn[K|M|G|T|P|E]
Define the size, in bytes, of the output pieces; the last one may, of
course, be shorter than this.  Any size smaller than 1024 will be
reset to 1024, and the size will always be rounded up to a multiple of
512 bytes.
.IP
The
.I integer
value
.I nnn
may be optionally followed by a multiplier suffix:
.IR K (kilo),
.IR M (mega),
.IR G (giga),
.IR T (tera),
.IR P (peta),
or
.IR E (exa).
These correspond to powers of the computer unit 1024, rather than the
usual 1000 of the metric system.
.IP
If this size option is omitted, then 1423K is assumed; this peculiar
number is the size of an IBM PC 3.5in high-density floppy disk, which
is a common file transfer medium.
.TP
.B \-h
Give a brief usage display on
.I stderr
and exit with a success status code.
.TP
.B \-v
Display the program version number and date on
.I stderr
and exit with a success status code.
.\"=====================================================================
.SH "SEE ALSO"
.BR mail (1),
.BR split (1),
.BR uucp (1C),
.BR uue (1),
.BR uuencode (1),
.BR uuencode (5),
.BR uusend (1C),
.BR uux (1C),
.BR xxencode (1).
.\"=====================================================================
.SH STATUS
This program and its manual page are placed in the
.I public
.IR domain .
.\"=====================================================================
.SH AUTHOR
.nf
Nelson H. F. Beebe
Center for Scientific Computing
University of Utah
Department of Mathematics, 110 LCB
155 S 1400 E RM 233
Salt Lake City, UT 84112-0090
USA
Email: \fCbeebe@math.utah.edu\fP, \fCbeebe@acm.org\fP, \fCbeebe@computer.org\fP (Internet)
WWW URL: \fChttp://www.math.utah.edu/~beebe\fP
FAX: +1 801 581 4148
Tel: +1 801 581 5254
.fi
