#ifndef XSTDLIB_H	/* file ignored if included more than once */
#define XSTDLIB_H

/**********************************************************************/
/****************************** stdlib ********************************/
/**********************************************************************/

/* $Id: xstdlib.h,v 1.12 1995/01/19 22:43:50 beebe Exp beebe $*/

/***********************************************************************
This file provides function prototype definitions for the C library.  It
can be used for environments where no system stdlib.h file is available,
such as for GNU gcc in non-ANSI UNIX C implementations.	 Note that some
older implementations may have different function return values, so some
care should be exercised in using this file.

Functions are ordered alphabetically below in two groups, each of two
sections, one with ANSI-style prototypes, and one with old-style
prototypes.

The first group contains the functions that belong to ANSI stdlib.h.

The second group contains miscellaneous other library functions that
have prototypes in other ANSI header files, but often lack prototypes in
typical non-ANSI C implementations.

[29-Jan-1992]
***********************************************************************/

#if    defined(HAVE_STDLIB_H)
#include <stdlib.h>
#else

/* Here is the contents of Standard C's stdlib.h.  Standard C reserves
names beginning with the regular expressions __ and _[A-Z] for
implementors, and C++ reserves names containing anywhere double
underscores.  To avoid conflict with such names, we use a single
trailing underscore instead for private names. */

#ifndef XTYPES_H
#include "xtypes.h" /* needed for types used below on some systems */
#endif

typedef int 				onexit_t;
typedef struct { int quot; int rem; }	div_t;
typedef struct { long quot; long rem; } ldiv_t;
typedef	unsigned int			wchar_t;

#ifdef ungetc
#undef ungetc		/* Turbo C macro conflicts with prototypes below */
#endif /* ungetc */

void		abort ARGS((void));
int		abs ARGS((int j_));
int		atexit ARGS((void (*func)(void)));
double		atof ARGS((const char *nptr_));
int		atoi ARGS((const char *nptr_));
long		atol ARGS((const char *nptr_));
char		*bsearch ARGS((const VOIDP key_,  const VOIDP base_,
		    size_t nmemb_, size_t size_,
		    int (*compar)(const VOIDP, const VOIDP )));
void		*calloc ARGS((size_t nmemb_,  size_t size_));
div_t		div ARGS((int numer_,  int denom_));
void		exit ARGS((int status_));
void		free ARGS((VOIDP ptr_));
char		*getenv ARGS((const char *name_));
long		labs ARGS((long j_));
ldiv_t		ldiv ARGS((long numer_,  long denom_));
void		*malloc ARGS((size_t size_));

#ifndef MB_CUR_MAX
#define	MB_CUR_MAX 4			/* this is SYSTEM-DEPENDENT */
#endif /* MB_CUR_MAX */

int		mblen ARGS((const char *s_, size_t n_));
size_t		mbstowcs ARGS((wchar_t *pwcs_, const char *s_, size_t n_));
int		mbtowc ARGS((wchar_t *pwc_, const char *s_, size_t n_));


onexit_t	onexit ARGS((onexit_t (*func)(void)));

#ifndef NULL
#if    KCC_20
/* has its own version in stdio.h */
#else  /* NOT KCC_20 */
#define NULL			((VOIDP) 0L)	/* this is SYSTEM-DEPENDENT */
#endif /* KCC_20 */
#endif /* NULL */

void		qsort ARGS((VOIDP base_,  size_t nmemb_,  size_t size_,
			int (*compar)(const VOIDP , const VOIDP )));
int		rand ARGS((void));

#ifndef RAND_MAX
#define	RAND_MAX 32767			/* this is SYSTEM-DEPENDENT */
#endif /* RAND_MAX */

void		*realloc ARGS((VOIDP ptr_,  size_t size_));
void		srand ARGS((unsigned int seed_));
double		strtod ARGS((const char *nptr_,  char** endptr_));
char		*strtok ARGS((char *s_, const char *sepchars_));
long		strtol ARGS((const char *nptr_,  char** endptr_,
		    int base_));
unsigned long	strtoul ARGS((const char *nptr_,  char** endptr_,
		    int base_));
int		system ARGS((const char *string_));
size_t		wcstombs ARGS((char *s_, const wchar_t *pwcs_, size_t n_));
int		wctomb ARGS((char *s_, wchar_t wchar_));

#endif /* defined(HAVE_STDLIB_H) */

#ifndef EXIT_FAILURE
#define EXIT_FAILURE	(1)
#endif /* EXIT_FAILURE */

#ifndef EXIT_SUCCESS
#define EXIT_SUCCESS	(0)
#endif /* EXIT_SUCCESS */

#ifndef NULL
#define NULL 0
#endif /* NULL */

#endif /* XSTDLIB_H */
