#ifndef XSTRING_H	/* file ignored if included more than once */
#define XSTRING_H

/**********************************************************************/
/****************************** string ********************************/
/**********************************************************************/

/* $Id: xstring.h,v 1.11 1995/05/17 12:36:36 beebe Exp beebe $*/

/* Standard C, System V, and BSD 4.3 call this <string.h>.  BSD 4.1 called it
<strings.h> */

#if defined(HAVE_STRING_H)
#include <string.h>		/* get the host version */

#if 0
#if defined(__cplusplus)
#undef HAVE_MEMXXX_DCL
#define HAVE_MEMXXX_DCL	1
#endif

#if    !HAVE_MEMXXX_DCL
/* Some systems have these in memory.h, but without argument
declarations, and sometimes, with wrong return types.  We use the
Standard C declarations here, rather than using memory.h, because the
latter causes other conflicts that we wish to avoid.  */
VOIDP		memccpy ARGS((VOIDP dest_,  const VOIDP src_,  int c_,
		    size_t n_));	/* Extension to Standard C */
VOIDP		memchr	ARGS((const VOIDP s_,  int c_,  size_t n_));
int		memcmp	ARGS((const VOIDP s1_,  const VOIDP s2_,
		    size_t n_));
VOIDP		memcpy	ARGS((VOIDP dest_,  const VOIDP src_,  size_t n_));
int		memicmp ARGS((const VOIDP s1_,  const VOIDP s2_,
		    size_t n_));	/* Extension to Standard C */
VOIDP		memmove ARGS((VOIDP dest_,  const VOIDP src_,  size_t n_));
VOIDP		memset	ARGS((VOIDP s_,  int c_,  size_t n_));
#endif /* !HAVE_MEMXXX_DCL */
#endif

#else /* !defined(HAVE_STRING_H) */

#include "xtypes.h"

/* Strictly, size_t must be defined in Standard C's string.h, but
since it is usually typedef'ed, e.g. "typedef long size_t" or "typedef
int size_t", sometimes with the unsigned attribute, we have no way of
checking here for a prior definition, so we can do nothing for it. */

#ifndef NULL
#if    KCC_20
/* has its own version in stdio.h */
#else  /* NOT KCC_20 */
#define NULL			((VOIDP) 0L)	/* this is SYSTEM-DEPENDENT */
#endif /* KCC_20 */
#endif /* NULL */

/* Some UNIX systems have the memxxx() functions in <memory.h>.
Standard C puts them in <string.h>. */

VOIDP		memccpy ARGS((VOIDP dest_,  const VOIDP src_,  int c_,
		    size_t n_));	/* Extension to Standard C */
VOIDP		memchr	ARGS((const VOIDP s_,  int c_,  size_t n_));
int		memcmp	ARGS((const VOIDP s1_,  const VOIDP s2_,
		    size_t n_));
VOIDP		memcpy	ARGS((VOIDP dest_,  const VOIDP src_,  size_t n_));
int		memicmp ARGS((const VOIDP s1_,  const VOIDP s2_,
		    size_t n_));	/* Extension to Standard C */
VOIDP		memmove ARGS((VOIDP dest_,  const VOIDP src_,  size_t n_));
VOIDP		memset	ARGS((VOIDP s_,  int c_,  size_t n_));
char		*strcat ARGS((char *s1_,  const char *s2_));
char		*strchr ARGS((const char *s_,  int character_));
int		strcmp ARGS((const char *s1_,  const char *s2_));
int		strcoll ARGS((const char *s1_, const char *s2_));
char		*strcpy ARGS((char *s1_,  const char *s2_));
size_t		strcspn ARGS((const char *s1_,  const char *s2_));
char		*strerror ARGS((int errnum_));
size_t		strlen ARGS((const char *s_));
char		*strncat ARGS((char *s1_,  const char *s2_,  size_t n_));
int		strncmp ARGS((const char *s1_,  const char *s2_,
		    size_t n_));
char		*strncpy ARGS((char *s1_,  const char *s2_,  size_t n_));
char		*strpbrk ARGS((const char *s1_,  const char *s2_));
char		*strrchr ARGS((const char *s_,  int character_));
size_t		strspn ARGS((const char *s1_,  const char *s2_));
char		*strstr ARGS((const char *s1_,  const char *s2_));
char		*strtok ARGS((char *s1_,  const char *s2_));
size_t		strxfrm ARGS((char *to_, const char *from_,
		    size_t maxsize_));
#endif /* defined(HAVE_STRING_H) */

/* Define a few private additional string functions used in the DVI
driver family */

int		stricmp ARGS((const char *, const char *));
char		*stristr ARGS((const char *s_, const char *sub_));
int		strnicmp ARGS((const char *s1_, const char *s2_, size_t n_));

#ifndef NULL
#define NULL 0
#endif /* NULL */

#endif /* XSTRING_H */
